/**
 * \file mcql/core/peptidelabel.h
 * \date 09/01/2025
 * \author Olivier Langella
 * \brief peptide label model in masschroqlite
 */

/*******************************************************************************
 * Copyright (c) 2025 Olivier Langella
 *<Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of MassChroQ.
 *
 *     MassChroQ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     MassChroQ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/


#include "peptidelabel.h"
#include <pappsomspp/peptide/peptideproformaparser.h>

mcql::PeptideLabel::PeptideLabel(const mcql::Peptide *peptide_p,
                                 const QString &label)
  : mp_mcqlPeptide(peptide_p)
{
  m_label = label;
}

mcql::PeptideLabel::~PeptideLabel()
{
  if(mpa_peptideNaturalIsotopeList != nullptr)
    delete mpa_peptideNaturalIsotopeList;
}

const QString &
mcql::PeptideLabel::getLabel() const
{
  return m_label;
}

void
mcql::PeptideLabel::setProforma(const QString &proforma)
{
  msp_peptide = pappso::PeptideProFormaParser::parseString(proforma);
}

void
mcql::PeptideLabel::computeIsotopologues(double ni_min_abundance)
{

  if(ni_min_abundance > 0)
    {
      qDebug() << "if (_minimum_isotope_abundance > 0)";
      mpa_peptideNaturalIsotopeList =
        new pappso::PeptideNaturalIsotopeList(msp_peptide, 0.001);
    }
}
