/**
 * \file mcql/core/peptidelabel.h
 * \date 09/01/2025
 * \author Olivier Langella
 * \brief peptide label model in masschroqlite
 */

/*******************************************************************************
 * Copyright (c) 2025 Olivier Langella
 *<Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of MassChroQ.
 *
 *     MassChroQ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     MassChroQ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/

#pragma once

#include "peptide.h"

namespace mcql
{

/**
 * @todo write docs
 */
class PeptideLabel
{
  public:
  /**
   * Default constructor
   */
  PeptideLabel(const mcql::Peptide *peptide_p, const QString &label);

  /**
   * Destructor
   */
  virtual ~PeptideLabel();

  const QString &getLabel() const;

  void setProforma(const QString &proforma);


  /** @brief compute possible isotopes for this molecule
   * @param ni_min_abundance the minimal isotop abundance proportion to cover
   * (0.9 will compute isotopes to reach at least 90% of its theoretical
   * abundance
   */
  void computeIsotopologues(double ni_min_abundance);


  private:
  const mcql::Peptide *mp_mcqlPeptide;
  QString m_label;

  pappso::PeptideNaturalIsotopeList *mpa_peptideNaturalIsotopeList = nullptr;

  pappso::PeptideSp msp_peptide;
};
} // namespace mcql
